Documentation
¶
Index ¶
Constants ¶
const AccessTokenLifetime = time.Hour
How long an access token will remain valid (1 hour)
const RefreshTokenLifetime = time.Hour * 24 * 30
How long a refresh token will remain valid (30 days)
Variables ¶
This section is empty.
Functions ¶
func CreateToken ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.